@@ -3,22 +3,21 @@
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
 
-#import <collections.h>
-#import <tkobjc.h>
-#import <simtools.h>
 #import <analysis.h>
+#import <simtools.h> // OutFile, ActiveOutFile
+#import <simtoolsgui.h> // ActiveGraph
 
 #define NUMCOLORS 10
-const char graphColors[NUMCOLORS][16] ={"Red", "Green", "Yellow", 
-                                        "Pink", "SeaGreen", "Magenta", 
-                                        "Purple", "DarkGreen", "Goldenrod", 
-                                        "Black"};
+const char graphColors[NUMCOLORS][16] = { "Red", "Green", "Yellow", 
+                                          "Pink", "SeaGreen", "Magenta", 
+                                          "Purple", "DarkGreen", "Goldenrod", 
+                                          "Black" };
 
 @implementation EZGraph
 
 + createBegin: aZone
 {
-  EZGraph * obj;
+  EZGraph *obj;
 
   obj = [super createBegin: aZone];
   obj->graphics = 1;
@@ -59,11 +58,11 @@ const char graphColors[NUMCOLORS][16] ={"Red", "Green", "Yellow",
 
   if (graphics)
     {
-      theGraph = [BLTGraph createBegin: [self getZone]];
+      theGraph = [Graph createBegin: [self getZone]];
       SET_COMPONENT_WINDOW_GEOMETRY_RECORD_NAME (theGraph);
       theGraph = [theGraph createEnd];
-      [theGraph title: title];
-      [theGraph axisLabelsX: xLabel Y: yLabel];
+      [theGraph setTitle: title];
+      [theGraph setAxisLabelsX: xLabel Y: yLabel];
       [theGraph pack];
     }
   
@@ -90,7 +89,8 @@ const char graphColors[NUMCOLORS][16] ={"Red", "Green", "Yellow",
       
       anElement = [theGraph createElement];
       [anElement setLabel: aName];
-      [anElement setColor: graphColors[ colorIdx++ % NUMCOLORS ] ];
+      [anElement setColor: graphColors[colorIdx++ % NUMCOLORS]];
+
       aGrapher = [ActiveGraph createBegin: [self getZone]];
       [aGrapher setElement: anElement];
       [aGrapher setDataFeed: anObj]; 
@@ -122,7 +122,7 @@ const char graphColors[NUMCOLORS][16] ={"Red", "Green", "Yellow",
 
 - createSequence: (const char *)aName
     withFeedFrom: anObj 
-     andSelector: (SEL) aSel
+     andSelector: (SEL)aSel
 {
   id aSeq;
   
@@ -161,7 +161,6 @@ const char graphColors[NUMCOLORS][16] ={"Red", "Green", "Yellow",
          withFeedFrom: aCollection 
           andSelector: (SEL)aSel
 {
-  
   id aSeq;
   id anAverager;
   
@@ -267,10 +266,11 @@ const char graphColors[NUMCOLORS][16] ={"Red", "Green", "Yellow",
   [theGraph drop];
 
   index = [sequenceList begin: [self getZone]];
-  while( (aSequence = [index next]) ){
-    [index remove];
-    [aSequence drop];
-  }
+  while ((aSequence = [index next]))
+    {
+      [index remove];
+      [aSequence drop];
+    }
   [index drop];
   [super drop];
 }
