@@ -1,4 +1,4 @@
-// Swarm library. Copyright (C) 1996-1997 Santa Fe Institute.
+// Swarm library. Copyright (C) 1996-1998 Santa Fe Institute.
 // This library is distributed without any warranty; without even the
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
@@ -11,7 +11,6 @@ Library:      defobj
 
 #import <defobj/Create.h>
 
-
 //
 // CreateDrop_s -- superclass for create protocol with phase switching
 //
@@ -44,13 +43,35 @@ PHASE(Creating)
 //
 - createEnd  
 {
-  createByCopy();
-  setNextPhase( self );
+  createByCopy ();
+  setNextPhase (self);
   return self;
 }
 
-@end
+PHASE(Using)
 
+- (const char *)getIdName
+{
+  return [self name];
+}
+
+- (const char *)getObjectName
+{
+  static char name[512];
+  
+  if (self)
+    {
+#ifdef __CYGWIN32__
+      sprintf (name, "%s@%p", [self name], self);
+#else
+      sprintf (name, "%s@0x%p", [self name], self);
+#endif
+      return name;
+    }
+  return "nil"; 
+}
+
+@end
 
 //
 // CreateDrop -- superclass for create protocol without phase switching
@@ -63,7 +84,7 @@ PHASE(Creating)
 //
 - createEnd  
 {
-  createByCopy();
+  createByCopy ();
   return self;
 }
 
