@@ -1,4 +1,4 @@
-// Swarm library. Copyright (C) 1996-1997 Santa Fe Institute.
+// Swarm library. Copyright (C) 1996-1998 Santa Fe Institute.
 // This library is distributed without any warranty; without even the
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
@@ -6,16 +6,23 @@
 #import <objectbase/SwarmObject.h>
 #import <tkobjc/Widget.h>
 
-@interface ArchivedGeometryWidget : Widget
+@interface ArchivedGeometryWidget: Widget
 {
   const char *windowGeometryRecordName;
+  id destroyNotificationTarget;
+  SEL destroyNotificationMethod;
+  BOOL destroyedFlag;
 }
 
-- setWindowGeometryRecordName : (const char *)recordName;
+- enableDestroyNotification: notificationTarget
+         notificationMethod: (SEL)destroyNotificationMethod;
+- disableDestroyNotification;
+- setWindowGeometryRecordName: (const char *)recordName;
 - loadWindowGeometryRecord;
 - updateArchiver;
 - createEnd;
 - registerAndLoad;
+- (BOOL)getDestroyedFlag;
 - (void)drop;
 
 @end
